@@ -10,7 +10,7 @@ from rich.table import Table
 from rich.text import Text
 
 from ..api.client import APIClient, APIError
-from ..api.sandbox import CreateSandboxRequest, Sandbox, SandboxClient
+from ..api.sandbox import BulkDeleteSandboxResponse, CreateSandboxRequest, Sandbox, SandboxClient
 from ..config import Config
 from ..utils import (
     build_table,
@@ -28,6 +28,8 @@ from ..utils.display import SANDBOX_STATUS_COLORS
 
 app = typer.Typer(help="Manage code sandboxes")
 console = Console()
+
+
 config = Config()
 
 
@@ -344,22 +346,141 @@ def create(
 
 @app.command()
 def delete(
-    sandbox_id: str,
+    sandbox_ids: Optional[List[str]] = typer.Argument(
+        None, help="Sandbox ID(s) to delete (space or comma-separated)"
+    ),
+    all: bool = typer.Option(False, "--all", help="Delete all sandboxes"),
     yes: bool = typer.Option(False, "--yes", "-y", help="Skip confirmation prompt"),
 ) -> None:
-    """Delete a sandbox"""
+    """Delete one or more sandboxes, or all sandboxes with --all"""
     try:
         base_client = APIClient()
         sandbox_client = SandboxClient(base_client)
 
-        if not confirm_or_skip(f"Are you sure you want to delete sandbox {sandbox_id}?", yes):
-            console.print("Delete cancelled")
-            raise typer.Exit(0)
+        # Validate arguments
+        if all and sandbox_ids:
+            console.print("[red]Error:[/red] Cannot specify both sandbox IDs and --all flag")
+            raise typer.Exit(1)
 
-        with console.status("[bold blue]Deleting sandbox...", spinner="dots"):
-            sandbox_client.delete(sandbox_id)
+        if not all and not sandbox_ids:
+            console.print("[red]Error:[/red] Must specify either sandbox IDs or --all flag")
+            raise typer.Exit(1)
 
-        console.print(f"[green]Successfully deleted sandbox {sandbox_id}[/green]")
+        if all:
+            # Get all sandboxes to delete
+            with console.status("[bold blue]Fetching all sandboxes...", spinner="dots"):
+                all_sandboxes = []
+                page = 1
+                while True:
+                    list_response = sandbox_client.list(
+                        per_page=100, page=page, exclude_terminated=False
+                    )
+                    all_sandboxes.extend(list_response.sandboxes)
+                    if not list_response.has_next:
+                        break
+                    page += 1
+
+                # Filter out already terminated sandboxes
+                active_sandboxes = [s for s in all_sandboxes if s.status != "TERMINATED"]
+                sandbox_ids = [s.id for s in active_sandboxes]
+
+                if not sandbox_ids:
+                    console.print("[yellow]No sandboxes to delete[/yellow]")
+                    raise typer.Exit(0)
+        else:
+            # Handle comma-separated IDs by splitting them
+            parsed_ids = []
+            for id_string in sandbox_ids or []:
+                # Split by comma and strip whitespace
+                if "," in id_string:
+                    parsed_ids.extend([id.strip() for id in id_string.split(",") if id.strip()])
+                else:
+                    parsed_ids.append(id_string.strip())
+
+            # Remove any empty strings and duplicates while preserving order
+            cleaned_ids = []
+            seen = set()
+            for id in parsed_ids:
+                if id and id not in seen:
+                    cleaned_ids.append(id)
+                    seen.add(id)
+
+            sandbox_ids = cleaned_ids
+
+        # Handle single vs multiple sandbox IDs
+        if len(sandbox_ids) == 1 and not all:
+            # Single sandbox deletion
+            sandbox_id = sandbox_ids[0]
+            if not confirm_or_skip(f"Are you sure you want to delete sandbox {sandbox_id}?", yes):
+                console.print("Delete cancelled")
+                raise typer.Exit(0)
+
+            with console.status("[bold blue]Deleting sandbox...", spinner="dots"):
+                sandbox_client.delete(sandbox_id)
+
+            console.print(f"[green]Successfully deleted sandbox {sandbox_id}[/green]")
+
+        else:
+            # Bulk sandbox deletion
+            if all:
+                confirmation_msg = (
+                    f"Are you sure you want to delete ALL {len(sandbox_ids)} "
+                    f"sandbox(es)? This action cannot be undone."
+                )
+                cancel_msg = "Delete all cancelled"
+            else:
+                confirmation_msg = (
+                    f"Are you sure you want to delete {len(sandbox_ids)} sandbox(es)?"
+                )
+                cancel_msg = "Bulk delete cancelled"
+
+            if not confirm_or_skip(confirmation_msg, yes):
+                console.print(cancel_msg)
+                raise typer.Exit(0)
+
+            # Batch the deletion into chunks of 100 to respect API limits
+            batch_size = 100
+            all_succeeded = []
+            all_failed = []
+
+            with console.status("[bold blue]Deleting sandboxes...", spinner="dots"):
+                for i in range(0, len(sandbox_ids), batch_size):
+                    batch = sandbox_ids[i : i + batch_size]
+                    batch_num = (i // batch_size) + 1
+                    total_batches = (len(sandbox_ids) + batch_size - 1) // batch_size
+
+                    console.print(
+                        f"[dim]Processing batch {batch_num}/{total_batches} "
+                        f"({len(batch)} sandboxes)...[/dim]"
+                    )
+
+                    result: BulkDeleteSandboxResponse = sandbox_client.bulk_delete(batch)
+
+                    if result.succeeded:
+                        all_succeeded.extend(result.succeeded)
+                    if result.failed:
+                        all_failed.extend(result.failed)
+
+            # Display combined results
+            total_processed = len(all_succeeded) + len(all_failed)
+            console.print(f"\n[green]Processed {total_processed} sandbox(es)[/green]")
+
+            if all_succeeded:
+                console.print(
+                    f"\n[bold green]Successfully deleted {len(all_succeeded)} "
+                    f"sandbox(es):[/bold green]"
+                )
+                for sandbox_id in all_succeeded:
+                    console.print(f"  ✓ {sandbox_id}")
+
+            if all_failed:
+                console.print(
+                    f"\n[bold red]Failed to delete {len(all_failed)} sandbox(es):[/bold red]"
+                )
+                for failure in all_failed:
+                    sandbox_id = failure.get("sandbox_id", "unknown")
+                    error = failure.get("error", "unknown error")
+                    console.print(f"  ✗ {sandbox_id}: {error}")
 
     except APIError as e:
         console.print(f"[red]Error:[/red] {str(e)}")
@@ -486,3 +607,120 @@ def run(
     except Exception as e:
         console.print(f"[red]Unexpected error:[/red] {str(e)}")
         raise typer.Exit(1)
+
+
+@app.command("upload")
+def upload_file(
+    sandbox_id: str = typer.Argument(..., help="Sandbox ID to upload file to"),
+    local_file: str = typer.Argument(..., help="Path to local file to upload"),
+    remote_path: str = typer.Argument(..., help="Path where file should be stored in sandbox"),
+) -> None:
+    """Upload a file to a sandbox"""
+    import os
+
+    try:
+        # Check if local file exists
+        if not os.path.exists(local_file):
+            console.print(f"[red]Error:[/red] Local file not found: {local_file}")
+            raise typer.Exit(1)
+
+        # Get file size for display
+        file_size = os.path.getsize(local_file)
+        filename = os.path.basename(local_file)
+
+        # If remote_path ends with '/', treat as directory
+        if remote_path.endswith("/"):
+            remote_path = remote_path.rstrip("/") + "/" + filename
+
+        base_client = APIClient()
+        sandbox_client = SandboxClient(base_client)
+
+        console.print(f"[bold blue]Uploading file:[/bold blue] {filename}")
+        console.print(f"[bold blue]From:[/bold blue] {local_file}")
+        console.print(f"[bold blue]To:[/bold blue] {remote_path}")
+        console.print(f"[bold blue]Size:[/bold blue] {file_size:,} bytes")
+
+        with console.status("[bold blue]Uploading...", spinner="dots"):
+            response = sandbox_client.upload_file(
+                sandbox_id=sandbox_id, file_path=remote_path, local_file_path=local_file
+            )
+
+        console.print("[green]✓[/green] File uploaded successfully!")
+        console.print(f"[bold green]Remote path:[/bold green] {response.path}")
+        console.print(f"[bold green]Size:[/bold green] {response.size:,} bytes")
+        console.print(f"[bold green]Timestamp:[/bold green] {response.timestamp}")
+
+    except APIError as e:
+        console.print(f"[red]Error:[/red] {str(e)}")
+        raise typer.Exit(1)
+    except Exception as e:
+        console.print(f"[red]Unexpected error:[/red] {str(e)}")
+        raise typer.Exit(1)
+
+
+@app.command("download")
+def download_file(
+    sandbox_id: str = typer.Argument(..., help="Sandbox ID to download file from"),
+    remote_path: str = typer.Argument(..., help="Path to file in sandbox"),
+    local_file: str = typer.Argument(..., help="Path where file should be saved locally"),
+) -> None:
+    """Download a file from a sandbox"""
+    import os
+
+    try:
+        # Check if local directory exists
+        local_dir = os.path.dirname(local_file)
+        if local_dir and not os.path.exists(local_dir):
+            console.print(f"[yellow]Warning:[/yellow] Creating directory: {local_dir}")
+            os.makedirs(local_dir, exist_ok=True)
+
+        # Check if local file already exists
+        if os.path.exists(local_file):
+            if not typer.confirm(f"File {local_file} already exists. Overwrite?"):
+                console.print("Download cancelled.")
+                raise typer.Exit(0)
+
+        base_client = APIClient()
+        sandbox_client = SandboxClient(base_client)
+
+        console.print(f"[bold blue]Downloading file from sandbox:[/bold blue] {sandbox_id}")
+        console.print(f"[bold blue]From:[/bold blue] {remote_path}")
+        console.print(f"[bold blue]To:[/bold blue] {local_file}")
+
+        with console.status("[bold blue]Downloading...", spinner="dots"):
+            sandbox_client.download_file(
+                sandbox_id=sandbox_id, file_path=remote_path, local_file_path=local_file
+            )
+
+        # Get downloaded file size for display
+        file_size = os.path.getsize(local_file) if os.path.exists(local_file) else 0
+
+        console.print("[green]✓[/green] File downloaded successfully!")
+        console.print(f"[bold green]Local path:[/bold green] {local_file}")
+        console.print(f"[bold green]Size:[/bold green] {file_size:,} bytes")
+
+    except APIError as e:
+        console.print(f"[red]Error:[/red] {str(e)}")
+        raise typer.Exit(1)
+    except FileNotFoundError as e:
+        console.print(f"[red]File not found:[/red] {str(e)}")
+        raise typer.Exit(1)
+    except Exception as e:
+        console.print(f"[red]Unexpected error:[/red] {str(e)}")
+        raise typer.Exit(1)
+
+
+@app.command("reset-cache")
+def reset_cache(
+    yes: bool = typer.Option(False, "--yes", "-y", help="Skip confirmation prompt"),
+) -> None:
+    """Reset sandbox authentication cache"""
+    if yes or typer.confirm("Are you sure you want to clear the sandbox auth cache?"):
+        try:
+            client = APIClient()
+            sandbox_client = SandboxClient(client)
+            sandbox_client.clear_auth_cache()
+            console.print("[green]Sandbox authentication cache cleared successfully![/green]")
+        except Exception as e:
+            console.print(f"[red]Error clearing cache: {e}[/red]")
+            raise typer.Exit(1)
